const fs = require('fs');
const path = require('path');

const dirName = path.dirname(module.filename);
const storePath = path.resolve(dirName, 'store.json');

function getAnimal(id) {
    return _readStore().then(animals => {
        if (animals[id]) {
            return animals[id];
        } else {
            throw new Error('There is no animal with id ' + id);
        }
    });
}

function getAnimals() {
    return _readStore().then(animals => {
        const animalsList = []
        for (let id in animals) {
            animalsList.push(animals[id]);
        }

        return animalsList;
    });
}

function addAnimal(id, name, age, weight) {
    return _readStore().then(animals => {
        animals[id] = { name, age, weight };
        return new Promise((resolve, reject) => {
            fs.writeFile(storePath, JSON.stringify(animals), error => {
                if (error) {
                    console.error(new Error('File writing error: ' + error.message));
                    reject(error);
                } else {
                    resolve(true);
                }
            });
        });
    });
}

function _readStore() {
    return new Promise(resolve => {
        fs.readFile(storePath, (error, data) => {
            const animals = JSON.parse(data);
            resolve(animals);
        });
    });
}

module.exports = {
    getAnimal,
    addAnimal,
    getAnimals
}
